/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.stock.project.visual;

import java.awt.Dimension;
import java.beans.PropertyChangeSupport;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSeparator;
import javax.swing.border.EtchedBorder;
import net.miginfocom.swing.MigLayout;
import nl.cloudfarming.client.crop.model.Crop;
import org.openide.util.NbBundle;
import org.openide.util.NbBundle.Messages;

/**
 *
 * Creates a panel with rows for each provided bean.
 * Will Display provided header label
 * Followed by a row of JLabel JTextField and a delete button.
 * On click of the delete button the row will be removed from the panel.
 * To listen to this changes register as PropertyChangeListener on property ListPanel.PROP_ROW
 * In the propertyChangeEvent the bean which is removed will be the old value
 * @author Merijn Zengers
 */
@Messages({
"stock.croplist.properties.crop_source.user_created=User created"

})
public class CropProperties extends JPanel { //implements PropertyChangeListener {

    private PropertyChangeSupport propertyChangeSupport;
    private static final int SEPARATOR_WIDTH = 300;
    private JLabel cropSourceLabel;
    private JLabel header;
    private JSeparator separator;
    public static final String PROP_ROW = "row";
    private String headerLabel;
    private JPanel innerPanel;
    private Crop crop;
    
    /**
     * This will construct a panel containing the following
     * A header filed with the value provided in @param headerLabel
     * For every bean in @param beans a row of:
     * A JLabel as provided in @param fieldLabel
     * A JTextField for filling the name of the bean
     * A delete button
     * On keyReleases on the JtextField the provided bean.setName() will be invoked with the text of the JTextField 
     * @param beans the beans to build rows for
     * @param headerLabel the Label for the header of the panel
     * @param fieldLabel the label for every field
     */
    CropProperties(Crop crop, String headerLabel) {
        this.crop = crop;
        this.headerLabel = headerLabel;
        init();
    }

    private void init() {
        this.setLayout(new MigLayout("wrap 1"));
        this.setBorder(new EtchedBorder(EtchedBorder.LOWERED));
        header = new JLabel(headerLabel);
        separator = new JSeparator(JSeparator.HORIZONTAL);
        separator.setPreferredSize(new Dimension(SEPARATOR_WIDTH, 0));
        
        this.add(header, "wrap");
        this.add(separator, "wrap");
        
        innerPanel = new JPanel();
        innerPanel.setLayout(new MigLayout("wrap 2, insets 0 0"));

        // Sets text of cropSourceLabel
        // TODO: Maybe this could be refactored into someting nicer
        String cropSource = crop.getSource();
        if(cropSource.equals(Crop.USER_INPUT)){         
            cropSourceLabel = new JLabel(NbBundle.getMessage(CropProperties.class, "stock.croplist.properties.crop_source.user_created"));
        }
        else{
            cropSourceLabel = new JLabel(cropSource);
        }
        
        // Property 'SOURCE'
        innerPanel.add(new JLabel("Crop source:"));
        innerPanel.add(cropSourceLabel);
        this.add(innerPanel);
    }

    public void setCrop(Crop crop){
        if(crop != null){
            cropSourceLabel.setText(crop.getSource());
        }
        else
        {
            cropSourceLabel.setText("");
        }

    }
}
